<?php
/*
Plugin Name: Pandasecurity Chat
Plugin URI: http://lin3s.com
Description: Pandasecurity Chat Plugin by LIN3S
Author: Asier Vega Unzueta
Version: 1.3.0
Author URI: http://lin3s.com
*/

// Block direct requests
if (!defined('ABSPATH'))
    die('-1');


add_action('widgets_init', function () {
    register_widget('Pandasecurity_Chat_Widget');
});

/**
 * Adds Pandasecurity Chat widget.
 */
class Pandasecurity_Chat_Widget extends WP_Widget
{
    private $aLocale = ['en_GB', 'en_US', 'es_ES', 'nl_NL'];
    private $text_domain = 'pandasecurity chat plugin';
    private $selectedLocale = '';

    /**
     * Register widget with WordPress.
     */
    function __construct()
    {
        parent::__construct(
            'Pandasecurity_Chat_Widget',
            __('Pandasecurity Chat', $this->text_domain),
            ['description' => __('Pandasecurity chat locale selector.', $this->text_domain),]
        );
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance)
    {
        if (array_key_exists('before_widget', $args)) {
            echo $args['before_widget'];
        }

        if ($instance['locale'] !== '') {
            $this->selectedLocale = $instance['locale'];
            $this->enqueueScripts();

            $code = "<section id='sticky_siempre_online' class='siempre_online'>";
            $code .= "<div class='contenedor'>";
            $code .= "<span class='texto_siempre_online'>" . __('Always online to help', $this->text_domain) . "</span>";
            $code .= "<span class='enlace_chat'>";
            $code .= "<a id='chat_sticky' class='chat' href='#'><span class='icon-ic-bullet'> </span>" . __('CHAT', $this->text_domain) . "</a>";
            $code .= "</span>";
            $code .= "</div>";
            $code .= "</section>";

            echo $code;
        } else {
            echo __('No locale selected.', $this->text_domain);
        }

        if (array_key_exists('after_widget', $args)) {
            echo $args['after_widget'];
        }
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form($instance)
    {
        if (isset($instance['locale'])) {
            $locale = $instance['locale'];
        } else {
            $locale = '';
        }

        $code = "<p>";
        $code .= "<label for='" . $this->get_field_id('locale') . "'>" . __('Locale:', $this->text_domain) . "</label>";
        $code .= "<select id='" . $this->get_field_id('locale') . "' name='" . $this->get_field_name('locale') . "'>";

        $selected = ('' == $locale) ? 'selected' : '';
        $code .= "<option" . $selected . " disabled>" . __('Choose here:', $this->text_domain) . "</option>";

        foreach ($this->aLocale as $aLocaleItem) {
            $selected = ($aLocaleItem == $locale) ? 'selected' : '';
            $code .= "<option value='" . $aLocaleItem . "' " . $selected . ">" . $aLocaleItem . "</option>";
        }

        $code .= "</select>";
        $code .= "</p>";

        echo $code;
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update($new_instance, $old_instance)
    {

        $instance = [];
        $instance['locale'] = (!empty($new_instance['locale'])) ? strip_tags($new_instance['locale']) : '';

        return $instance;
    }

    /**
     * Callback that allows to enqueue plugin scripts.
     */
    public function enqueueScripts()
    {
        wp_enqueue_style('pandasecurity_chat', plugin_dir_url(__FILE__) . '/css/chat.css');
        wp_enqueue_script('pandasecurity_chat_info', $this->getChatInfoURL($this->selectedLocale), ['jquery']);
        wp_enqueue_script('pandasecurity_chat_soporte', plugin_dir_url(__FILE__) . '/js/chat-support-' . $this->selectedLocale . '.js', ['jquery']);
    }

    public function getChatInfoURL($locale)
    {
        $url = 'http://islpronto.islonline.net/live/islpronto/public/chat_info.js';
        switch ($locale) {
            case 'en_GB':
                $url .= '?d=pandasecurity.com&lang=sv&filter=swe_consum';
                break;
            case 'en_US':
                $url .= '?d=pandasecurity.com&lang=en&filter=usa_consum,usa_corpo';
                break;
            case 'es_ES':
                $url .= '?d=pandasecurity.com&lang=es&filter=Soporte_Consumo,Soporte_corpo';
                break;
            case 'nl_NL':
                $url .= '?d=pandasecurity.com&lang=nl&filter=be_consum,be_corpo';
                break;
        }

        return $url;
    }
}
